@@ -5,6 +5,8 @@ from .outputs import *
 # FILES HANDLING
 
 def aLoad(fileHandler: dict): # Automatic loading.
+	from .settings import data
+
 	handler = {}
 
 	handler["path"] = ""
@@ -13,14 +15,14 @@ def aLoad(fileHandler: dict): # Automatic loading.
 	handler.update(fileHandler)
 
 	try:
-		dataFile = open(handler["path"], "rb")
+		dataFile = open(handler["path"] + data.setting_fileExtension, "rb")
 		data = load(dataFile)
 		dataFile.close()
 				
 	except(FileNotFoundError):
 		data = None
 		if not handler["ignoreMissing"]:
-			output({"type": "error", "string": "\'" + fileHandler["path"] + "\' NOT FOUND"})
+			output({"type": "error", "string": "\'" + fileHandler["path"] + data.setting_fileExtension + "\' NOT FOUND"})
 
 	except:
 		data = None
@@ -29,6 +31,8 @@ def aLoad(fileHandler: dict): # Automatic loading.
 	return data
 	
 def aDump(fileHandler: dict) -> None: # Automatic dumping.
+	from .settings import data
+	
 	handler = {}
 
 	handler["path"] = ""
@@ -37,7 +41,7 @@ def aDump(fileHandler: dict) -> None: # Automatic dumping.
 	handler.update(fileHandler)
 
 	try:
-		dataFile = open(handler["path"], "wb")
+		dataFile = open(handler["path"] + data.setting_fileExtension, "wb")
 		dump(handler["data"], dataFile)
 		dataFile.close()
 	
